@@ -28,7 +28,7 @@ class FineTuneParser(GPUParser):
 		handler0.addFilter(HostnameFilter())
 		fmt0 = "<{hostname:^10s}>: " + fmt
 
-		if self._args.logfile is None:
+		if self._args.logfile in [ None, "" ] :
 			filename = f"{platform.node()}.log"
 		else:
 			filename = self._args.logfile
